## Набор плагинов обмена данных с РС для РИС.

### Сокращения

РИС — Региональная информационная система в сфере образования. В БАРС такими информационными системами являются ЭШ, ЭДС, ЭК, ЭДО.

РС — Региональный сегмент ИС Контингент Обучающихся.

### Структура
В данном пакете содержатся плагины:
  - передачи данных из РИС в РС — datatransfer.source;
  - передачи данных из РС в РИС — datatransfer.source.get_data;
  - журнала взаимодействия между РС и РИС — datatransfer.source.catalog.

### Сборка
    python setup.py sdist
    

